window.Gleam.initSearch([{"doc":"webls","title":"webls","content":"# WebLS\n\nA Gleam library for generating sitemaps and RSS feeds and more. to meet all\nyour common web listing needs.\n\n[![Package Version](https://img.shields.io/hexpm/v/webls)](https://hex.pm/packages/webls)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/webls/)\n\n```sh\ngleam add webls\n```\n\n```gleam\nimport webls/sitemap\nimport webls/rss\nimport webls/robots\n\npub fn sitemap() -&gt; String {\n  sitemap.sitemap(&quot;https://gleam.run/sitemap.xml&quot;)\n  |&gt; sitemap.with_sitemap_last_modified(birl.now())\n  |&gt; sitemap.with_sitemap_items([\n    sitemap.item(&quot;https://gleam.run&quot;)\n      |&gt; sitemap.with_item_frequency(sitemap.Monthly)\n      |&gt; sitemap.with_item_priority(1.0),\n    sitemap.item(&quot;https://gleam.run/blog&quot;)\n      |&gt; sitemap.with_item_frequency(sitemap.Weekly),\n    sitemap.item(&quot;https://gleam.run/blog/gleam-1.0&quot;),\n    sitemap.item(&quot;https://gleam.run/blog/gleam-1.1&quot;),\n  ]) |&gt; sitemap.to_string()\n}\n\npub fn rss() -&gt; String {\n  [\n    rss.channel(&quot;Gleam RSS&quot;, &quot;A test RSS feed&quot;, &quot;https://gleam.run&quot;)\n    |&gt; rss.with_channel_category(&quot;Releases&quot;)\n    |&gt; rss.with_channel_language(&quot;en&quot;)\n    |&gt; rss.with_channel_items([\n      rss.item(&quot;Gleam 1.0&quot;, &quot;Gleam 1.0 is here!&quot;)\n        |&gt; rss.with_item_link(&quot;https://gleam.run/blog/gleam-1.0&quot;)\n        |&gt; rss.with_item_pub_date(birl.now())\n        |&gt; rss.with_item_guid(#(&quot;gleam 1.0&quot;, Some(False))),\n      rss.item(&quot;Gleam 0.10&quot;, &quot;Gleam 0.10 is here!&quot;)\n        |&gt; rss.with_item_link(&quot;https://gleam.run/blog/gleam-0.10&quot;)\n        |&gt; rss.with_item_author(&quot;user@example.com&quot;)\n        |&gt; rss.with_item_guid(#(&quot;gleam 0.10&quot;, Some(True))),\n    ]),\n  ] |&gt; rss.to_string()\n}\n\npub fn robots() -&gt; String {\n  robots.config(&quot;https://example.com/sitemap.xml&quot;)\n  |&gt; robots.with_config_robots([\n    robots.robot(&quot;googlebot&quot;)\n      |&gt; robots.with_robot_allowed_routes([&quot;/posts/&quot;, &quot;/contact/&quot;])\n      |&gt; robots.with_robot_disallowed_routes([&quot;/admin/&quot;, &quot;/private/&quot;]),\n    robots.robot(&quot;bingbot&quot;)\n      |&gt; robots.with_robot_allowed_routes([&quot;/posts/&quot;, &quot;/contact/&quot;, &quot;/private/&quot;])\n      |&gt; robots.with_robot_disallowed_routes([&quot;/&quot;]),\n  ])\n  |&gt; robots.to_string()\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/webls&gt;.\n\n## Current Standards Compliance\n\n| Protocol   | Version  | Status   |\n| ---------- | -------- | -------- |\n| Sitemaps   | 0.9      | Complete |\n| RSS        | 2.0.1    | Complete |\n| Robots.txt | 1997 IDS | Complete |\n\n&gt; A Note on the RSS 2.0 spec, the PICS field for content ratings is not going\n&gt; to be supported as the PICS standard was discontinued more than a decade ago.\n\n## Utility Support\n\n| Type       | to_string | Builder Functions | Validators |\n| ---------- | --------- | ----------------- | ---------- |\n| Sitemap    | Complete  | Complete          | None       |\n| RSS v2.0   | Complete  | Complete          | None       |\n| Robots.txt | Complete  | Complete          | None       |\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n&gt; Yes the name is a reference to the `ls` command in unix to list files\n","url":"index.html"},{"doc":"webls/robots","title":"Robot","content":"pub type Robot {\n  Robot(\n    user_agent: String,\n    allowed_routes: List(String),\n    disallowed_routes: List(String),\n  )\n}\n The policy for a specific robot\nRobot(\n  user_agent: String,\n  allowed_routes: List(String),\n  disallowed_routes: List(String),\n)\n\nuser_agent\n&lt;p&gt;The user agent such as “googlebot” or “*” for catch all&lt;/p&gt;\n\nallowed_routes\n&lt;p&gt;The allowed routes such as “/posts/” and “/contact/”&lt;/p&gt;\n\ndisallowed_routes\n&lt;p&gt;The disallowed routes such as “/admin/” and “/private/”&lt;/p&gt;\n\nSynonyms:\nwebls/robots.Robot\nwebls/robots Robot","url":"webls/robots.html#Robot"},{"doc":"webls/robots","title":"RobotsConfig","content":"pub type RobotsConfig {\n  RobotsConfig(sitemap_url: String, robots: List(Robot))\n}\n The configuration for a robots.txt file\nRobotsConfig(sitemap_url: String, robots: List(Robot))\n\nsitemap_url\n&lt;p&gt;The url of the sitemap for crawlers to use&lt;/p&gt;\n\nrobots\n&lt;p&gt;A list of robot policies&lt;/p&gt;\n\nSynonyms:\nwebls/robots.RobotsConfig\nwebls/robots RobotsConfig","url":"webls/robots.html#RobotsConfig"},{"doc":"webls/robots","title":"config","content":"pub fn config(sitemap_url: String) -&gt; RobotsConfig\n Creates a robots config with a sitemap url\nSynonyms:\nwebls/robots.config\nwebls/robots config","url":"webls/robots.html#config"},{"doc":"webls/robots","title":"robot","content":"pub fn robot(user_agent: String) -&gt; Robot\n Creates a robot policy\nSynonyms:\nwebls/robots.robot\nwebls/robots robot","url":"webls/robots.html#robot"},{"doc":"webls/robots","title":"to_string","content":"pub fn to_string(config: RobotsConfig) -&gt; String\n\nSynonyms:\nwebls/robots.to_string\nwebls/robots to_string","url":"webls/robots.html#to_string"},{"doc":"webls/robots","title":"with_config_robot","content":"pub fn with_config_robot(\n  config: RobotsConfig,\n  robot: Robot,\n) -&gt; RobotsConfig\n Adds a robot to the robots config\nSynonyms:\nwebls/robots.with_config_robot\nwebls/robots with_config_robot","url":"webls/robots.html#with_config_robot"},{"doc":"webls/robots","title":"with_config_robots","content":"pub fn with_config_robots(\n  config: RobotsConfig,\n  robots: List(Robot),\n) -&gt; RobotsConfig\n Adds a list of robots to the robots config\nSynonyms:\nwebls/robots.with_config_robots\nwebls/robots with_config_robots","url":"webls/robots.html#with_config_robots"},{"doc":"webls/robots","title":"with_robot_allowed_route","content":"pub fn with_robot_allowed_route(\n  robot: Robot,\n  route: String,\n) -&gt; Robot\n Adds a allowed route to the robot policy\nSynonyms:\nwebls/robots.with_robot_allowed_route\nwebls/robots with_robot_allowed_route","url":"webls/robots.html#with_robot_allowed_route"},{"doc":"webls/robots","title":"with_robot_allowed_routes","content":"pub fn with_robot_allowed_routes(\n  robot: Robot,\n  routes: List(String),\n) -&gt; Robot\n Adds a list of allowed routes to the robot policy\nSynonyms:\nwebls/robots.with_robot_allowed_routes\nwebls/robots with_robot_allowed_routes","url":"webls/robots.html#with_robot_allowed_routes"},{"doc":"webls/robots","title":"with_robot_disallowed_route","content":"pub fn with_robot_disallowed_route(\n  robot: Robot,\n  route: String,\n) -&gt; Robot\n Adds a disallowed route to the robot policy\nSynonyms:\nwebls/robots.with_robot_disallowed_route\nwebls/robots with_robot_disallowed_route","url":"webls/robots.html#with_robot_disallowed_route"},{"doc":"webls/robots","title":"with_robot_disallowed_routes","content":"pub fn with_robot_disallowed_routes(\n  robot: Robot,\n  routes: List(String),\n) -&gt; Robot\n Adds a list of disallowed routes to the robot policy\nSynonyms:\nwebls/robots.with_robot_disallowed_routes\nwebls/robots with_robot_disallowed_routes","url":"webls/robots.html#with_robot_disallowed_routes"},{"doc":"webls/robots","title":"webls/robots","content":"","url":"webls/robots.html"},{"doc":"webls/rss","title":"Cloud","content":"pub type Cloud {\n  Cloud(\n    domain: String,\n    port: Int,\n    path: String,\n    register_procedure: String,\n    protocol: String,\n  )\n}\n Cloud configuration for an RSS channel\nCloud(\n  domain: String,\n  port: Int,\n  path: String,\n  register_procedure: String,\n  protocol: String,\n)\n\ndomain\n&lt;p&gt;The domain of the cloud service&lt;/p&gt;\n\nport\n&lt;p&gt;The port for the cloud service&lt;/p&gt;\n\npath\n&lt;p&gt;The path for the cloud service&lt;/p&gt;\n\nregister_procedure\n&lt;p&gt;The registration procedure for the cloud service (usually “http-post” or “xml-rpc”)&lt;/p&gt;\n\nprotocol\n&lt;p&gt;The protocol used for the cloud service&lt;/p&gt;\n\nSynonyms:\nwebls/rss.Cloud\nwebls/rss Cloud","url":"webls/rss.html#Cloud"},{"doc":"webls/rss","title":"Enclosure","content":"pub type Enclosure {\n  Enclosure(url: String, length: Int, enclosure_type: String)\n}\n An enclosure resource for an RSS item\nEnclosure(url: String, length: Int, enclosure_type: String)\n\nurl\n&lt;p&gt;The URL of the enclosure resource&lt;/p&gt;\n\nlength\n&lt;p&gt;The length of the enclosure in bytes&lt;/p&gt;\n\nenclosure_type\n&lt;p&gt;The type of the enclosure (e.g., audio/mpeg, video/mp4)&lt;/p&gt;\n\nSynonyms:\nwebls/rss.Enclosure\nwebls/rss Enclosure","url":"webls/rss.html#Enclosure"},{"doc":"webls/rss","title":"Image","content":"pub type Image {\n  Image(\n    url: String,\n    title: String,\n    link: String,\n    description: Option(String),\n    width: Option(Int),\n    height: Option(Int),\n  )\n}\n An image associated with a RSS channel\nImage(\n  url: String,\n  title: String,\n  link: String,\n  description: Option(String),\n  width: Option(Int),\n  height: Option(Int),\n)\n\nurl\n&lt;p&gt;The URL of the image&lt;/p&gt;\n\ntitle\n&lt;p&gt;The title of the image&lt;/p&gt;\n\nlink\n&lt;p&gt;The link associated with the image&lt;/p&gt;\n\ndescription\n&lt;p&gt;An optional description of the image&lt;/p&gt;\n\nwidth\n&lt;p&gt;An optional width of the image in pixels&lt;/p&gt;\n\nheight\n&lt;p&gt;An optional height of the image in pixels&lt;/p&gt;\n\nSynonyms:\nwebls/rss.Image\nwebls/rss Image","url":"webls/rss.html#Image"},{"doc":"webls/rss","title":"RssChannel","content":"pub type RssChannel {\n  RssChannel(\n    title: String,\n    link: String,\n    description: String,\n    language: Option(String),\n    copyright: Option(String),\n    managing_editor: Option(String),\n    web_master: Option(String),\n    pub_date: Option(Time),\n    last_build_date: Option(Time),\n    categories: List(String),\n    generator: Option(String),\n    docs: Option(String),\n    cloud: Option(Cloud),\n    ttl: Option(Int),\n    image: Option(Image),\n    text_input: Option(TextInput),\n    skip_hours: List(Int),\n    skip_days: List(birl.Weekday),\n    items: List(RssItem),\n  )\n}\n RSS 2.0.1 spec compliant channel\nRssChannel(\n  title: String,\n  link: String,\n  description: String,\n  language: Option(String),\n  copyright: Option(String),\n  managing_editor: Option(String),\n  web_master: Option(String),\n  pub_date: Option(Time),\n  last_build_date: Option(Time),\n  categories: List(String),\n  generator: Option(String),\n  docs: Option(String),\n  cloud: Option(Cloud),\n  ttl: Option(Int),\n  image: Option(Image),\n  text_input: Option(TextInput),\n  skip_hours: List(Int),\n  skip_days: List(birl.Weekday),\n  items: List(RssItem),\n)\n\ntitle\n&lt;p&gt;The title of the RSS channel&lt;/p&gt;\n\nlink\n&lt;p&gt;The link to the top page of the RSS channel&lt;/p&gt;\n\ndescription\n&lt;p&gt;The description of the RSS channel&lt;/p&gt;\n\nlanguage\n&lt;p&gt;The language of the RSS channel&lt;/p&gt;\n\ncopyright\n&lt;p&gt;The copyright information for the RSS channel&lt;/p&gt;\n\nmanaging_editor\n&lt;p&gt;The managing editor’s email address&lt;/p&gt;\n\nweb_master\n&lt;p&gt;The web master’s email address&lt;/p&gt;\n\npub_date\n&lt;p&gt;The publication date of the RSS channel&lt;/p&gt;\n\nlast_build_date\n&lt;p&gt;The last build date of the RSS channel&lt;/p&gt;\n\ncategories\n&lt;p&gt;A list of categories for the RSS channel&lt;/p&gt;\n\ngenerator\n&lt;p&gt;The generator program of the RSS channel, feel free to shout webls out!&lt;/p&gt;\n\ndocs\n&lt;p&gt;A link to the documentation for the RSS spec&lt;/p&gt;\n\ncloud\n&lt;p&gt;Cloud configuration for the RSS channel&lt;/p&gt;\n\nttl\n&lt;p&gt;The time-to-live (TTL) for the RSS channel&lt;/p&gt;\n\nimage\n&lt;p&gt;An optional image associated with the RSS channel&lt;/p&gt;\n\ntext_input\n&lt;p&gt;An optional text input for the RSS channel&lt;/p&gt;\n\nskip_hours\n&lt;p&gt;A list of hours in GMT which content aggregation should be skipped&lt;/p&gt;\n\nskip_days\n&lt;p&gt;A list of days to skip in the RSS channel&lt;/p&gt;\n\nitems\n&lt;p&gt;A list of items in the RSS channel&lt;/p&gt;\n\nSynonyms:\nwebls/rss.RssChannel\nwebls/rss RssChannel","url":"webls/rss.html#RssChannel"},{"doc":"webls/rss","title":"RssItem","content":"pub type RssItem {\n  RssItem(\n    title: String,\n    description: String,\n    link: Option(String),\n    author: Option(String),\n    comments: Option(String),\n    source: Option(String),\n    pub_date: Option(Time),\n    categories: List(String),\n    enclosure: Option(Enclosure),\n    guid: Option(#(String, Option(Bool))),\n  )\n}\n RSS 2.0.1 spec compliant item\nRssItem(\n  title: String,\n  description: String,\n  link: Option(String),\n  author: Option(String),\n  comments: Option(String),\n  source: Option(String),\n  pub_date: Option(Time),\n  categories: List(String),\n  enclosure: Option(Enclosure),\n  guid: Option(#(String, Option(Bool))),\n)\n\ntitle\n&lt;p&gt;The title of the RSS item&lt;/p&gt;\n\ndescription\n&lt;p&gt;The description of the RSS item&lt;/p&gt;\n\nlink\n&lt;p&gt;The link to the page or source of the RSS item&lt;/p&gt;\n\nauthor\n&lt;p&gt;An optional author field, note RSS author must be email addresses&lt;/p&gt;\n\ncomments\n&lt;p&gt;A URL to the comments section for the RSS item&lt;/p&gt;\n\nsource\n&lt;p&gt;The RSS channel the item came from&lt;/p&gt;\n\npub_date\n&lt;p&gt;The publication date of the RSS item&lt;/p&gt;\n\ncategories\n&lt;p&gt;A list of categories for the RSS item&lt;/p&gt;\n\nenclosure\n&lt;p&gt;An optional enclosure resource for the RSS item&lt;/p&gt;\n\nguid\n&lt;p&gt;A guid and an optional boolean for whether it is a permalink&lt;/p&gt;\n\nSynonyms:\nwebls/rss.RssItem\nwebls/rss RssItem","url":"webls/rss.html#RssItem"},{"doc":"webls/rss","title":"TextInput","content":"pub type TextInput {\n  TextInput(\n    title: String,\n    description: String,\n    name: String,\n    link: String,\n  )\n}\n A text input field for an RSS channel\nTextInput(\n  title: String,\n  description: String,\n  name: String,\n  link: String,\n)\n\ntitle\n&lt;p&gt;The title of the text input field&lt;/p&gt;\n\ndescription\n&lt;p&gt;A description of the text input field’s purpose&lt;/p&gt;\n\nname\n&lt;p&gt;The name attribute for the text input field&lt;/p&gt;\n\nlink\n&lt;p&gt;The link associated with the text input field&lt;/p&gt;\n\nSynonyms:\nwebls/rss.TextInput\nwebls/rss TextInput","url":"webls/rss.html#TextInput"},{"doc":"webls/rss","title":"channel","content":"pub fn channel(\n  title: String,\n  description: String,\n  link: String,\n) -&gt; RssChannel\n Creates a base RSS channel\nSynonyms:\nwebls/rss.channel\nwebls/rss channel","url":"webls/rss.html#channel"},{"doc":"webls/rss","title":"item","content":"pub fn item(title: String, description: String) -&gt; RssItem\n Creates a base RSS item\nSynonyms:\nwebls/rss.item\nwebls/rss item","url":"webls/rss.html#item"},{"doc":"webls/rss","title":"to_string","content":"pub fn to_string(channels: List(RssChannel)) -&gt; String\n Converts a list of RSS channels to a string of a valid RSS 2.0.1 feed\nSynonyms:\nwebls/rss.to_string\nwebls/rss to_string","url":"webls/rss.html#to_string"},{"doc":"webls/rss","title":"with_channel_categories","content":"pub fn with_channel_categories(\n  channel: RssChannel,\n  categories: List(String),\n) -&gt; RssChannel\n Adds a list of categories to the RSS channel\nSynonyms:\nwebls/rss.with_channel_categories\nwebls/rss with_channel_categories","url":"webls/rss.html#with_channel_categories"},{"doc":"webls/rss","title":"with_channel_category","content":"pub fn with_channel_category(\n  channel: RssChannel,\n  category: String,\n) -&gt; RssChannel\n Adds a category to the RSS channel\nSynonyms:\nwebls/rss.with_channel_category\nwebls/rss with_channel_category","url":"webls/rss.html#with_channel_category"},{"doc":"webls/rss","title":"with_channel_cloud","content":"pub fn with_channel_cloud(\n  channel: RssChannel,\n  cloud: Cloud,\n) -&gt; RssChannel\n Sets the cloud element for the RSS channel with a domain, port, path,\n register procedure, and protocol\nSynonyms:\nwebls/rss.with_channel_cloud\nwebls/rss with_channel_cloud","url":"webls/rss.html#with_channel_cloud"},{"doc":"webls/rss","title":"with_channel_copyright","content":"pub fn with_channel_copyright(\n  channel: RssChannel,\n  copyright: String,\n) -&gt; RssChannel\n Sets the copyright information for the RSS channel\nSynonyms:\nwebls/rss.with_channel_copyright\nwebls/rss with_channel_copyright","url":"webls/rss.html#with_channel_copyright"},{"doc":"webls/rss","title":"with_channel_custom_generator","content":"pub fn with_channel_custom_generator(\n  channel: RssChannel,\n  generator: String,\n) -&gt; RssChannel\n Sets the generator element for the RSS channel with a custom string\nSynonyms:\nwebls/rss.with_channel_custom_generator\nwebls/rss with_channel_custom_generator","url":"webls/rss.html#with_channel_custom_generator"},{"doc":"webls/rss","title":"with_channel_docs","content":"pub fn with_channel_docs(channel: RssChannel) -&gt; RssChannel\n Adds the RSS 2.0.1 spec documentation link to the RSS channel\nSynonyms:\nwebls/rss.with_channel_docs\nwebls/rss with_channel_docs","url":"webls/rss.html#with_channel_docs"},{"doc":"webls/rss","title":"with_channel_generator","content":"pub fn with_channel_generator(channel: RssChannel) -&gt; RssChannel\n Sets the generator element for the RSS channel to webls\nSynonyms:\nwebls/rss.with_channel_generator\nwebls/rss with_channel_generator","url":"webls/rss.html#with_channel_generator"},{"doc":"webls/rss","title":"with_channel_image","content":"pub fn with_channel_image(\n  channel: RssChannel,\n  image: Image,\n) -&gt; RssChannel\n Sets an optional image associated with the RSS channel\nSynonyms:\nwebls/rss.with_channel_image\nwebls/rss with_channel_image","url":"webls/rss.html#with_channel_image"},{"doc":"webls/rss","title":"with_channel_item","content":"pub fn with_channel_item(\n  channel: RssChannel,\n  item: RssItem,\n) -&gt; RssChannel\n Adds a RSS item to the RSS channel\nSynonyms:\nwebls/rss.with_channel_item\nwebls/rss with_channel_item","url":"webls/rss.html#with_channel_item"},{"doc":"webls/rss","title":"with_channel_items","content":"pub fn with_channel_items(\n  channel: RssChannel,\n  items: List(RssItem),\n) -&gt; RssChannel\n Adds a list of items in the RSS channel\nSynonyms:\nwebls/rss.with_channel_items\nwebls/rss with_channel_items","url":"webls/rss.html#with_channel_items"},{"doc":"webls/rss","title":"with_channel_language","content":"pub fn with_channel_language(\n  channel: RssChannel,\n  language: String,\n) -&gt; RssChannel\n Sets the language of the RSS channel example: &quot;en-us&quot;\nSynonyms:\nwebls/rss.with_channel_language\nwebls/rss with_channel_language","url":"webls/rss.html#with_channel_language"},{"doc":"webls/rss","title":"with_channel_last_build_date","content":"pub fn with_channel_last_build_date(\n  channel: RssChannel,\n  last_build_date: Time,\n) -&gt; RssChannel\n Sets the last build date of the RSS channel\nSynonyms:\nwebls/rss.with_channel_last_build_date\nwebls/rss with_channel_last_build_date","url":"webls/rss.html#with_channel_last_build_date"},{"doc":"webls/rss","title":"with_channel_managing_editor","content":"pub fn with_channel_managing_editor(\n  channel: RssChannel,\n  managing_editor: String,\n) -&gt; RssChannel\n Sets the managing editor&#39;s email address for the RSS channel\nSynonyms:\nwebls/rss.with_channel_managing_editor\nwebls/rss with_channel_managing_editor","url":"webls/rss.html#with_channel_managing_editor"},{"doc":"webls/rss","title":"with_channel_pub_date","content":"pub fn with_channel_pub_date(\n  channel: RssChannel,\n  pub_date: Time,\n) -&gt; RssChannel\n Sets the publication date of the RSS channel\nSynonyms:\nwebls/rss.with_channel_pub_date\nwebls/rss with_channel_pub_date","url":"webls/rss.html#with_channel_pub_date"},{"doc":"webls/rss","title":"with_channel_skip_days","content":"pub fn with_channel_skip_days(\n  channel: RssChannel,\n  skip_days: List(Weekday),\n) -&gt; RssChannel\n Sets a list of days to skip in the RSS channel\nSynonyms:\nwebls/rss.with_channel_skip_days\nwebls/rss with_channel_skip_days","url":"webls/rss.html#with_channel_skip_days"},{"doc":"webls/rss","title":"with_channel_skip_hours","content":"pub fn with_channel_skip_hours(\n  channel: RssChannel,\n  skip_hours: List(Int),\n) -&gt; RssChannel\n Sets a list of hours in GMT which content aggregation should be skipped\nSynonyms:\nwebls/rss.with_channel_skip_hours\nwebls/rss with_channel_skip_hours","url":"webls/rss.html#with_channel_skip_hours"},{"doc":"webls/rss","title":"with_channel_text_input","content":"pub fn with_channel_text_input(\n  channel: RssChannel,\n  text_input: TextInput,\n) -&gt; RssChannel\n Sets an optional text input for the RSS channel\nSynonyms:\nwebls/rss.with_channel_text_input\nwebls/rss with_channel_text_input","url":"webls/rss.html#with_channel_text_input"},{"doc":"webls/rss","title":"with_channel_ttl","content":"pub fn with_channel_ttl(\n  channel: RssChannel,\n  ttl: Int,\n) -&gt; RssChannel\n Sets the time-to-live (TTL) for the RSS channel in minutes\nSynonyms:\nwebls/rss.with_channel_ttl\nwebls/rss with_channel_ttl","url":"webls/rss.html#with_channel_ttl"},{"doc":"webls/rss","title":"with_channel_web_master","content":"pub fn with_channel_web_master(\n  channel: RssChannel,\n  web_master: String,\n) -&gt; RssChannel\n Sets the web master&#39;s email address for the RSS channel\nSynonyms:\nwebls/rss.with_channel_web_master\nwebls/rss with_channel_web_master","url":"webls/rss.html#with_channel_web_master"},{"doc":"webls/rss","title":"with_item_author","content":"pub fn with_item_author(item: RssItem, author: String) -&gt; RssItem\n Sets an optional author field, note RSS author must be email addresses\nSynonyms:\nwebls/rss.with_item_author\nwebls/rss with_item_author","url":"webls/rss.html#with_item_author"},{"doc":"webls/rss","title":"with_item_categories","content":"pub fn with_item_categories(\n  item: RssItem,\n  categories: List(String),\n) -&gt; RssItem\n Sets a list of categories for the RSS item\nSynonyms:\nwebls/rss.with_item_categories\nwebls/rss with_item_categories","url":"webls/rss.html#with_item_categories"},{"doc":"webls/rss","title":"with_item_comments","content":"pub fn with_item_comments(\n  item: RssItem,\n  comments: String,\n) -&gt; RssItem\n Sets a URL to the comments section for the RSS item\nSynonyms:\nwebls/rss.with_item_comments\nwebls/rss with_item_comments","url":"webls/rss.html#with_item_comments"},{"doc":"webls/rss","title":"with_item_enclosure","content":"pub fn with_item_enclosure(\n  item: RssItem,\n  enclosure: Enclosure,\n) -&gt; RssItem\n Sets an optional enclosure (media resource) for the RSS item\nSynonyms:\nwebls/rss.with_item_enclosure\nwebls/rss with_item_enclosure","url":"webls/rss.html#with_item_enclosure"},{"doc":"webls/rss","title":"with_item_guid","content":"pub fn with_item_guid(\n  item: RssItem,\n  guid: #(String, Option(Bool)),\n) -&gt; RssItem\n Sets the guid of the RSS item with an optional boolean for whether it is a permalink\nSynonyms:\nwebls/rss.with_item_guid\nwebls/rss with_item_guid","url":"webls/rss.html#with_item_guid"},{"doc":"webls/rss","title":"with_item_link","content":"pub fn with_item_link(item: RssItem, link: String) -&gt; RssItem\n Sets the link to the page or source of the RSS item\nSynonyms:\nwebls/rss.with_item_link\nwebls/rss with_item_link","url":"webls/rss.html#with_item_link"},{"doc":"webls/rss","title":"with_item_pub_date","content":"pub fn with_item_pub_date(\n  item: RssItem,\n  pub_date: Time,\n) -&gt; RssItem\n Sets the publication date of the RSS item\nSynonyms:\nwebls/rss.with_item_pub_date\nwebls/rss with_item_pub_date","url":"webls/rss.html#with_item_pub_date"},{"doc":"webls/rss","title":"with_item_source","content":"pub fn with_item_source(item: RssItem, source: String) -&gt; RssItem\n Sets the RSS channel the item came from\nSynonyms:\nwebls/rss.with_item_source\nwebls/rss with_item_source","url":"webls/rss.html#with_item_source"},{"doc":"webls/rss","title":"webls/rss","content":"","url":"webls/rss.html"},{"doc":"webls/sitemap","title":"ChangeFrequency","content":"pub type ChangeFrequency {\n  Always\n  Hourly\n  Daily\n  Weekly\n  Monthly\n  Yearly\n  Never\n}\n The fequency at which a page tends to change\nAlways\n\n\nHourly\n\n\nDaily\n\n\nWeekly\n\n\nMonthly\n\n\nYearly\n\n\nNever\n\n\nSynonyms:\nwebls/sitemap.ChangeFrequency\nwebls/sitemap ChangeFrequency","url":"webls/sitemap.html#ChangeFrequency"},{"doc":"webls/sitemap","title":"Sitemap","content":"pub type Sitemap {\n  Sitemap(\n    url: String,\n    last_modified: Option(Time),\n    items: List(SitemapItem),\n  )\n}\n A complete sitemap\nSitemap(\n  url: String,\n  last_modified: Option(Time),\n  items: List(SitemapItem),\n)\n\nurl\n&lt;p&gt;The url location of the sitemap&lt;/p&gt;\n\nlast_modified\n&lt;p&gt;The time of last modification of the sitemap&lt;/p&gt;\n\nitems\n&lt;p&gt;The list of items contained within the sitemap&lt;/p&gt;\n\nSynonyms:\nwebls/sitemap.Sitemap\nwebls/sitemap Sitemap","url":"webls/sitemap.html#Sitemap"},{"doc":"webls/sitemap","title":"SitemapItem","content":"pub type SitemapItem {\n  SitemapItem(\n    loc: String,\n    last_modified: Option(Time),\n    change_frequency: Option(ChangeFrequency),\n    priority: Option(Float),\n  )\n}\n A item within a sitemap\nSitemapItem(\n  loc: String,\n  last_modified: Option(Time),\n  change_frequency: Option(ChangeFrequency),\n  priority: Option(Float),\n)\n\nloc\n&lt;p&gt;The location/url of the page&lt;/p&gt;\n\nlast_modified\n&lt;p&gt;The time of last modification of the page&lt;/p&gt;\n\nchange_frequency\n&lt;p&gt;How frequently the page is likely to continue to change&lt;/p&gt;\n\npriority\n&lt;p&gt;The priority of the page compared to others within the sitemap\nMust be between 0.0 and 1.0&lt;/p&gt;\n\nSynonyms:\nwebls/sitemap.SitemapItem\nwebls/sitemap SitemapItem","url":"webls/sitemap.html#SitemapItem"},{"doc":"webls/sitemap","title":"item","content":"pub fn item(loc: String) -&gt; SitemapItem\n Create a base sitemap item with just the URL location\nSynonyms:\nwebls/sitemap.item\nwebls/sitemap item","url":"webls/sitemap.html#item"},{"doc":"webls/sitemap","title":"sitemap","content":"pub fn sitemap(url: String) -&gt; Sitemap\n Create a sitemap with a url\nSynonyms:\nwebls/sitemap.sitemap\nwebls/sitemap sitemap","url":"webls/sitemap.html#sitemap"},{"doc":"webls/sitemap","title":"to_string","content":"pub fn to_string(sitemap: Sitemap) -&gt; String\n Generates a sitemap.xml string from a sitemap\nSynonyms:\nwebls/sitemap.to_string\nwebls/sitemap to_string","url":"webls/sitemap.html#to_string"},{"doc":"webls/sitemap","title":"with_item_frequency","content":"pub fn with_item_frequency(\n  item: SitemapItem,\n  frequency: ChangeFrequency,\n) -&gt; SitemapItem\n Add a change frequency to the sitemap item\nSynonyms:\nwebls/sitemap.with_item_frequency\nwebls/sitemap with_item_frequency","url":"webls/sitemap.html#with_item_frequency"},{"doc":"webls/sitemap","title":"with_item_last_modified","content":"pub fn with_item_last_modified(\n  item: SitemapItem,\n  modified: Time,\n) -&gt; SitemapItem\n Add a last modified time to the sitemap item\nSynonyms:\nwebls/sitemap.with_item_last_modified\nwebls/sitemap with_item_last_modified","url":"webls/sitemap.html#with_item_last_modified"},{"doc":"webls/sitemap","title":"with_item_priority","content":"pub fn with_item_priority(\n  item: SitemapItem,\n  priority: Float,\n) -&gt; SitemapItem\n Add a priority to the sitemap item\nSynonyms:\nwebls/sitemap.with_item_priority\nwebls/sitemap with_item_priority","url":"webls/sitemap.html#with_item_priority"},{"doc":"webls/sitemap","title":"with_sitemap_item","content":"pub fn with_sitemap_item(\n  sitemap: Sitemap,\n  item: SitemapItem,\n) -&gt; Sitemap\n Adds a sitemap item to the sitemap\nSynonyms:\nwebls/sitemap.with_sitemap_item\nwebls/sitemap with_sitemap_item","url":"webls/sitemap.html#with_sitemap_item"},{"doc":"webls/sitemap","title":"with_sitemap_items","content":"pub fn with_sitemap_items(\n  sitemap: Sitemap,\n  items: List(SitemapItem),\n) -&gt; Sitemap\n Adds a list of sitemap items to the sitemap\nSynonyms:\nwebls/sitemap.with_sitemap_items\nwebls/sitemap with_sitemap_items","url":"webls/sitemap.html#with_sitemap_items"},{"doc":"webls/sitemap","title":"with_sitemap_last_modified","content":"pub fn with_sitemap_last_modified(\n  sitemap: Sitemap,\n  last_modified: Time,\n) -&gt; Sitemap\n Add a last modified time to the sitemap\nSynonyms:\nwebls/sitemap.with_sitemap_last_modified\nwebls/sitemap with_sitemap_last_modified","url":"webls/sitemap.html#with_sitemap_last_modified"},{"doc":"webls/sitemap","title":"webls/sitemap","content":"","url":"webls/sitemap.html"}]);